@@ -10,28 +10,28 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.22';
+$VERSION = '0.23';
 $DATE = '2004/05/24';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Test_STDmaker.pm' => [qw(0.22 2004/05/24), 'revised 0.21'],
-    'MANIFEST' => [qw(0.22 2004/05/24), 'generated, replaces 0.21'],
-    'Makefile.PL' => [qw(0.22 2004/05/24), 'generated, replaces 0.21'],
-    'README' => [qw(0.22 2004/05/24), 'generated, replaces 0.21'],
-    'lib/Test/STDmaker.pm' => [qw(1.21 2004/05/24), 'revised 1.2'],
+    'lib/Docs/Site_SVD/Test_STDmaker.pm' => [qw(0.23 2004/05/24), 'revised 0.22'],
+    'MANIFEST' => [qw(0.23 2004/05/24), 'generated, replaces 0.22'],
+    'Makefile.PL' => [qw(0.23 2004/05/24), 'generated, replaces 0.22'],
+    'README' => [qw(0.23 2004/05/24), 'generated, replaces 0.22'],
+    'lib/Test/STDmaker.pm' => [qw(1.21 2004/05/24), 'unchanged'],
     'lib/Test/STDmaker/Check.pm' => [qw(1.15 2004/05/23), 'unchanged'],
     'lib/Test/STDmaker/Demo.pm' => [qw(1.14 2004/05/21), 'unchanged'],
     'lib/Test/STDmaker/STD.pm' => [qw(1.12 2004/05/23), 'unchanged'],
     'lib/Test/STDmaker/Verify.pm' => [qw(1.15 2004/05/22), 'unchanged'],
     'lib/Test/STD/PerlSTD.pm' => [qw(1.08 2004/05/19), 'unchanged'],
-    't/Test/STDmaker/advance.d' => [qw(0.01 2004/05/24), 'new'],
-    't/Test/STDmaker/advance.pm' => [qw(0.01 2004/05/24), 'new'],
-    't/Test/STDmaker/advance.t' => [qw(0.01 2004/05/24), 'new'],
-    't/Test/STDmaker/basic.d' => [qw(0.01 2004/05/24), 'new'],
-    't/Test/STDmaker/basic.pm' => [qw(0.01 2004/05/24), 'new'],
-    't/Test/STDmaker/basic.t' => [qw(0.01 2004/05/24), 'new'],
+    't/Test/STDmaker/advance.d' => [qw(0.01 2004/05/24), 'unchanged'],
+    't/Test/STDmaker/advance.pm' => [qw(0.01 2004/05/24), 'unchanged'],
+    't/Test/STDmaker/advance.t' => [qw(0.01 2004/05/24), 'unchanged'],
+    't/Test/STDmaker/basic.d' => [qw(0.01 2004/05/24), 'unchanged'],
+    't/Test/STDmaker/basic.pm' => [qw(0.01 2004/05/24), 'unchanged'],
+    't/Test/STDmaker/basic.t' => [qw(0.01 2004/05/24), 'unchanged'],
     't/Test/STDmaker/tg0.pm' => [qw(0.03 2004/04/09), 'unchanged'],
     't/Test/STDmaker/tg2A.pm' => [qw(0.06 2004/05/23), 'unchanged'],
     't/Test/STDmaker/tg2B.pm' => [qw(0.07 2004/05/23), 'unchanged'],
@@ -39,7 +39,7 @@ use vars qw(%INVENTORY);
     't/Test/STDmaker/tgA2.pm' => [qw(0.09 2004/05/23), 'unchanged'],
     't/Test/STDmaker/tgA2A2.txt' => [qw(0.13 2004/05/23), 'unchanged'],
     't/Test/STDmaker/tgA2A3.txt' => [qw(0.13 2004/05/23), 'unchanged'],
-    't/Test/STDmaker/tgA2B.txt' => [qw(0.09 2004/05/22), 'unchanged'],
+    't/Test/STDmaker/tgA2B.txt' => [qw(0.1 2004/05/24), 'revised 0.09'],
     't/Test/STDmaker/tgA2C.txt' => [qw(0.1 2004/05/22), 'unchanged'],
     't/Test/STDmaker/tgB0.pm' => [qw(0.02 2004/05/18), 'unchanged'],
     't/Test/STDmaker/tgB2.pm' => [qw(0.04 2004/05/23), 'unchanged'],
@@ -48,7 +48,7 @@ use vars qw(%INVENTORY);
     't/Test/STDmaker/tgC2.pm' => [qw(0.06 2004/05/23), 'unchanged'],
     't/Test/STDmaker/tgD0.pm' => [qw(0.06 2004/05/22), 'unchanged'],
     't/Test/STDmaker/tmake.pl' => [qw(1.06 2004/05/24), 'unchanged'],
-    't/Test/STDmaker/Text/Scrub.pm' => [qw(1.15 2004/05/24), 'unchanged'],
+    't/Test/STDmaker/Text/Scrub.pm' => [qw(1.16 2004/05/24), 'revised 1.15'],
     't/Test/STDmaker/Test/Tech.pm' => [qw(1.26 2004/05/24), 'unchanged'],
     't/Test/STDmaker/Data/Secs2.pm' => [qw(1.26 2004/05/24), 'unchanged'],
     't/Test/STDmaker/Data/Str2Num.pm' => [qw(0.08 2004/05/24), 'unchanged'],
@@ -83,9 +83,9 @@ Docs::Site_SVD::Test_STDmaker - generate test scripts, demo scripts from a test
 
  Docs::Site_SVD::Test_STDmaker - generate test scripts, demo scripts from a test description short hand
 
- Revision: T
+ Revision: U
 
- Version: 0.22
+ Version: 0.23
 
  Date: 2004/05/24
 
@@ -176,7 +176,7 @@ further detail on the text database fields and the processing.
 
 =head2 1.3 Document overview.
 
-This document releases Test::STDmaker version 0.22
+This document releases Test::STDmaker version 0.23
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -191,7 +191,7 @@ system file specification.
 
 This document releases the file 
 
- Test-STDmaker-0.22.tar.gz
+ Test-STDmaker-0.23.tar.gz
 
 found at the following repository(s):
 
@@ -278,22 +278,22 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Test_STDmaker.pm                           0.22    2004/05/24 revised 0.21
- MANIFEST                                                     0.22    2004/05/24 generated, replaces 0.21
- Makefile.PL                                                  0.22    2004/05/24 generated, replaces 0.21
- README                                                       0.22    2004/05/24 generated, replaces 0.21
- lib/Test/STDmaker.pm                                         1.21    2004/05/24 revised 1.2
+ lib/Docs/Site_SVD/Test_STDmaker.pm                           0.23    2004/05/24 revised 0.22
+ MANIFEST                                                     0.23    2004/05/24 generated, replaces 0.22
+ Makefile.PL                                                  0.23    2004/05/24 generated, replaces 0.22
+ README                                                       0.23    2004/05/24 generated, replaces 0.22
+ lib/Test/STDmaker.pm                                         1.21    2004/05/24 unchanged
  lib/Test/STDmaker/Check.pm                                   1.15    2004/05/23 unchanged
  lib/Test/STDmaker/Demo.pm                                    1.14    2004/05/21 unchanged
  lib/Test/STDmaker/STD.pm                                     1.12    2004/05/23 unchanged
  lib/Test/STDmaker/Verify.pm                                  1.15    2004/05/22 unchanged
  lib/Test/STD/PerlSTD.pm                                      1.08    2004/05/19 unchanged
- t/Test/STDmaker/advance.d                                    0.01    2004/05/24 new
- t/Test/STDmaker/advance.pm                                   0.01    2004/05/24 new
- t/Test/STDmaker/advance.t                                    0.01    2004/05/24 new
- t/Test/STDmaker/basic.d                                      0.01    2004/05/24 new
- t/Test/STDmaker/basic.pm                                     0.01    2004/05/24 new
- t/Test/STDmaker/basic.t                                      0.01    2004/05/24 new
+ t/Test/STDmaker/advance.d                                    0.01    2004/05/24 unchanged
+ t/Test/STDmaker/advance.pm                                   0.01    2004/05/24 unchanged
+ t/Test/STDmaker/advance.t                                    0.01    2004/05/24 unchanged
+ t/Test/STDmaker/basic.d                                      0.01    2004/05/24 unchanged
+ t/Test/STDmaker/basic.pm                                     0.01    2004/05/24 unchanged
+ t/Test/STDmaker/basic.t                                      0.01    2004/05/24 unchanged
  t/Test/STDmaker/tg0.pm                                       0.03    2004/04/09 unchanged
  t/Test/STDmaker/tg2A.pm                                      0.06    2004/05/23 unchanged
  t/Test/STDmaker/tg2B.pm                                      0.07    2004/05/23 unchanged
@@ -301,7 +301,7 @@ consists of the following files:
  t/Test/STDmaker/tgA2.pm                                      0.09    2004/05/23 unchanged
  t/Test/STDmaker/tgA2A2.txt                                   0.13    2004/05/23 unchanged
  t/Test/STDmaker/tgA2A3.txt                                   0.13    2004/05/23 unchanged
- t/Test/STDmaker/tgA2B.txt                                    0.09    2004/05/22 unchanged
+ t/Test/STDmaker/tgA2B.txt                                    0.1     2004/05/24 revised 0.09
  t/Test/STDmaker/tgA2C.txt                                    0.1     2004/05/22 unchanged
  t/Test/STDmaker/tgB0.pm                                      0.02    2004/05/18 unchanged
  t/Test/STDmaker/tgB2.pm                                      0.04    2004/05/23 unchanged
@@ -310,7 +310,7 @@ consists of the following files:
  t/Test/STDmaker/tgC2.pm                                      0.06    2004/05/23 unchanged
  t/Test/STDmaker/tgD0.pm                                      0.06    2004/05/22 unchanged
  t/Test/STDmaker/tmake.pl                                     1.06    2004/05/24 unchanged
- t/Test/STDmaker/Text/Scrub.pm                                1.15    2004/05/24 unchanged
+ t/Test/STDmaker/Text/Scrub.pm                                1.16    2004/05/24 revised 1.15
  t/Test/STDmaker/Test/Tech.pm                                 1.26    2004/05/24 unchanged
  t/Test/STDmaker/Data/Secs2.pm                                1.26    2004/05/24 unchanged
  t/Test/STDmaker/Data/Str2Num.pm                              0.08    2004/05/24 unchanged
@@ -577,7 +577,8 @@ Corrective Action:
 
 Backed out test descriptions that producde curly brackets except for C<BEGIN> and C<END>
 blocks of generated scripts. 
-The backed test descriptions can be added as another test once get some green PASSES.
+The backed test descriptions are added to the C<advance.t> test script that
+will not be distributed until get some green PASSES for the C<basic.t> test script.
 
 =item Test-STDmaker-0.19 - Test-STDmaker-0.21
 
@@ -589,19 +590,16 @@ Test Failure:
  "my" variable $expected1 masks earlier declaration in same scope at tgA1.d line 203.
  "my" variable $x masks earlier declaration in same scope at tgA1.d line 228.
  "my" variable $y masks earlier declaration in same scope at tgA1.d line 233.
- "my" variable $expected1 masks earlier declaration in same scope at tgA1.t line 240.
- "my" variable $x masks earlier declaration in same scope at tgA1.t line 252.
- "my" variable $y masks earlier declaration in same scope at tgA1.t line 257.
 
 Analysis:
 
-Opening a new C<tmaker> for test 9, involked C<File::Maker> methods a second time for
+Opening a new C<tmaker> for test 9, involked C<File::Maker> load methods a second time for
 the same program module C<__DATA__> section. While these work under Windows, they
 are completely messed up under Unix. 
 
 Corrective Action:
 
-Changed the order of the test script C<tmaker> never created with the C<new> subroutine
+Changed the order of the test script so C<tmaker> never created with the C<new> subroutine
 for the same file object. 
 Add making C<File::Maker> work with loading the C<__DATA__> twice after loading the program
 module on the todo list. 
@@ -617,7 +615,7 @@ Analysis:
 
 No error stack output yet failing tests. There are only 21 tests.
 
-Corective Action
+Corrective Action
 
 Found where main test script redirecting STDERR output to STDOUT. Removed
 it. This is needed for the test case scripts that are ran by the main scripts
@@ -625,7 +623,46 @@ in order to grab STDERR output to compare with expected results.
 
 Split the test script into C<basic.t> and C<advance.t> and moved the last three tests
 to the advance.t test script. The focus will be to baseline with the C<basic.t>
-test script only.
+test script only. Once have a baseline with some Passes, work on getting the
+C<advance.t> to pass on multi-platforms.
+
+=item Test-STDmaker-0.23
+
+Some passes, a Failure:
+
+From: mhoyt@houston.rr.com 
+Subject: FAIL Test-STDmaker-0.22 darwin-thread-multi-2level 7.0 
+
+t/Test/STDmaker/basic....# Test 9 got: 
+"1..11 todo 3 6;
+ok 1 - Quiet Code 
+ok 2 - Pass test 
+ok 3 - Todo test that passes  # (xxxx.t at line 000 TODO?!)
+not ok 4 - Test that fails 
+# Test 4 got: \"6\" (xxxx.t at line 000)
+#   Expected: \"7\"\nok 5 - Skipped tests  # skip
+not ok 6 - Todo Test that Fails 
+
+"1..11 todo 3 6;
+ok 1 - Quiet Code 
+ok 2 - Pass test 
+ok 3 - Todo test that passes  # (xxxx.t at line 000 TODO?!)
+not ok 4 - Test that fails 
+# Test 4 got: '6' (xxxx.t at line 000)
+#   Expected: '7'\nok 5 - Skipped tests  # skip
+not ok 6 - Todo Test that Fails 
+
+Analysis:
+
+Most Perls return single quotes around numbers; however,
+darwin-thread-multi-2level 7.0, and probably others
+return double quotes.
+This could be a function of the C<Test> module version.
+
+Corrective Action:
+
+Added code to C<&Test::Scrub::scrub_file_line> to change double quotes
+around numbers to single quotes 
 
 =back
 
@@ -665,13 +702,13 @@ Enter one of the following repositories in a web browser:
   http://www.softwarediamonds/packages/
   http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 
-Right click on 'Test-STDmaker-0.22.tar.gz' and download to a temporary
+Right click on 'Test-STDmaker-0.23.tar.gz' and download to a temporary
 installation directory.
 Enter the following where $make is 'nmake' for microsoft
 windows; otherwise 'make'.
 
- gunzip Test-STDmaker-0.22.tar.gz
- tar -xf Test-STDmaker-0.22.tar
+ gunzip Test-STDmaker-0.23.tar.gz
+ tar -xf Test-STDmaker-0.23.tar
  perl Makefile.PL
  $make test
  $make install
@@ -730,13 +767,10 @@ contact
 
 =over 4
 
+
 =item 1
 
-Establish all the requirements.
-
-=item 2
-
-Get pass on with the C<advance.t> test script on
+Introduce the C<advance.t> test script and get it to pass on 
 Unix type machines.
 
 =back
@@ -824,10 +858,10 @@ __DATA__
 DISTNAME: Test-STDmaker^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.22^
+VERSION : 0.23^
 FREEZE: 1^
-PREVIOUS_RELEASE: 0.21^
-REVISION: T^
+PREVIOUS_RELEASE: 0.22^
+REVISION: U^
 
 PREVIOUS_DISTNAME:  ^
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
@@ -1211,7 +1245,8 @@ Corrective Action:
 
 Backed out test descriptions that producde curly brackets except for C<BEGIN> and C<END>
 blocks of generated scripts. 
-The backed test descriptions can be added as another test once get some green PASSES.
+The backed test descriptions are added to the C<advance.t> test script that
+will not be distributed until get some green PASSES for the C<basic.t> test script.
 
 \=item Test-STDmaker-0.19 - Test-STDmaker-0.21
 
@@ -1223,19 +1258,16 @@ Test Failure:
  "my" variable $expected1 masks earlier declaration in same scope at tgA1.d line 203.
  "my" variable $x masks earlier declaration in same scope at tgA1.d line 228.
  "my" variable $y masks earlier declaration in same scope at tgA1.d line 233.
- "my" variable $expected1 masks earlier declaration in same scope at tgA1.t line 240.
- "my" variable $x masks earlier declaration in same scope at tgA1.t line 252.
- "my" variable $y masks earlier declaration in same scope at tgA1.t line 257.
 
 Analysis:
 
-Opening a new C<tmaker> for test 9, involked C<File::Maker> methods a second time for
+Opening a new C<tmaker> for test 9, involked C<File::Maker> load methods a second time for
 the same program module C<__DATA__> section. While these work under Windows, they
 are completely messed up under Unix. 
 
 Corrective Action:
 
-Changed the order of the test script C<tmaker> never created with the C<new> subroutine
+Changed the order of the test script so C<tmaker> never created with the C<new> subroutine
 for the same file object. 
 Add making C<File::Maker> work with loading the C<__DATA__> twice after loading the program
 module on the todo list. 
@@ -1251,7 +1283,7 @@ Analysis:
 
 No error stack output yet failing tests. There are only 21 tests.
 
-Corective Action
+Corrective Action
 
 Found where main test script redirecting STDERR output to STDOUT. Removed
 it. This is needed for the test case scripts that are ran by the main scripts
@@ -1259,7 +1291,46 @@ in order to grab STDERR output to compare with expected results.
 
 Split the test script into C<basic.t> and C<advance.t> and moved the last three tests
 to the advance.t test script. The focus will be to baseline with the C<basic.t>
-test script only.
+test script only. Once have a baseline with some Passes, work on getting the
+C<advance.t> to pass on multi-platforms.
+
+\=item Test-STDmaker-0.23
+
+Some passes, a Failure:
+
+From: mhoyt@houston.rr.com 
+Subject: FAIL Test-STDmaker-0.22 darwin-thread-multi-2level 7.0 
+
+t/Test/STDmaker/basic....# Test 9 got: 
+"1..11 todo 3 6;
+ok 1 - Quiet Code 
+ok 2 - Pass test 
+ok 3 - Todo test that passes  # (xxxx.t at line 000 TODO?!)
+not ok 4 - Test that fails 
+# Test 4 got: \"6\" (xxxx.t at line 000)
+#   Expected: \"7\"\nok 5 - Skipped tests  # skip
+not ok 6 - Todo Test that Fails 
+
+"1..11 todo 3 6;
+ok 1 - Quiet Code 
+ok 2 - Pass test 
+ok 3 - Todo test that passes  # (xxxx.t at line 000 TODO?!)
+not ok 4 - Test that fails 
+# Test 4 got: '6' (xxxx.t at line 000)
+#   Expected: '7'\nok 5 - Skipped tests  # skip
+not ok 6 - Todo Test that Fails 
+
+Analysis:
+
+Most Perls return single quotes around numbers; however,
+darwin-thread-multi-2level 7.0, and probably others
+return double quotes.
+This could be a function of the C<Test> module version.
+
+Corrective Action:
+
+Added code to C<&Test::Scrub::scrub_file_line> to change double quotes
+around numbers to single quotes 
 
 \=back
 
@@ -1269,13 +1340,10 @@ PROBLEMS:
 
 \=over 4
 
+
 \=item 1
 
-Establish all the requirements.
-
-\=item 2
-
-Get pass on with the C<advance.t> test script on
+Introduce the C<advance.t> test script and get it to pass on 
 Unix type machines.
 
 \=back
@@ -1534,6 +1602,14 @@ HTML: ^
 
 
 
+
+
+
+
+
+
+
+
 
 
 
